@@ -1,4 +1,4 @@
-def identify_adducts(df, masses, custom_adducts = None, method = "spearman", threshold = 0.90, mass_error = 2):
+def identify_adducts(df, masses, custom_adducts = None, method = "pearson", threshold = 0.90, mass_error = 2):
     
     """Finds different ion species of a single analyte molecule. 
     Computes pointwise correlation of XIC traces to identify in-source adducts or in-source fragments
@@ -24,7 +24,7 @@ def identify_adducts(df, masses, custom_adducts = None, method = "spearman", thr
                   custom_adducts = pd.DataFrame({'deltamz': [mz1, mz2, mz3],
                                                  'motive': ["motive1", "motive2", "motive3"]}). 
     
-    method : str, {‘spearman’, 'pearson’, ‘kendall’}
+    method : str, {'pearson’, ‘spearman’, ‘kendall’}
             Correlation method for pointwise compariation of XIC traces. 
             
     threshold : float
@@ -46,7 +46,7 @@ def identify_adducts(df, masses, custom_adducts = None, method = "spearman", thr
         
     See Also
     --------
-    align_spectra(), impute_intensities() : For preparation of the input data.
+    DBDIpy.align_spectra(), DBDIpy.impute_intensities() : For preparation of the input data.
     
     """
 #%%library import 
