@@ -2,6 +2,7 @@ import pandas as pd
 import numpy as np
 import feather
 import matplotlib.pyplot as plt
+import DBDIpy as dbdi
 
 ##macOS
 intensities_raw = feather.read_dataframe("/Users/lw/Nextcloud/Project212/src/data/example_dataset.feather")
@@ -22,7 +23,18 @@ df = intensities_raw.copy()
 
 #%%test imputation module
 
-raw_imp = impute_intensities(intensities_raw, method = "linear")
+raw_imp = dbdi.impute_intensities(intensities_raw, method = "linear")
+
+raw_imp_lin = dbdi.impute_intensities(intensities_raw, method = "linear")
+raw_imp_quad = dbdi.impute_intensities(intensities_raw, method = "quadratic")
+raw_imp_ind = dbdi.impute_intensities(intensities_raw, method = "previous")
+
+test = raw_imp_lin.subtract(raw_imp_pol)
+
+("linear", "index", "pad", "nearest", "slinear", 
+"quadratic", "cubic", "barycentric", "zero",
+"krogh", "from_derivatives")
+
 
 ## indices of oxygen series from C15H17O2N 55 -> 66 ->> 83 ->>> 99
 #%%setup corr mudule
@@ -36,9 +48,9 @@ masses = annotation_metadata.iloc[:,3]
 
 threshold = 0.95
 
-adducts =  identify_adducts(raw_imp, annotation_metadata["ThMass.Ion"], 
+adducts =  dbdi.identify_adducts(raw_imp, annotation_metadata["ThMass.Ion"], 
                          custom_adducts = pd.DataFrame({'deltamz': [47.984744], 'motive': ["O3"]}),
-                         method = "spearman", threshold = 0.9, mass_error = 5)
+                         method = "spearman", threshold = 0.95, mass_error = 5)
    
 
 
@@ -87,7 +99,7 @@ IDs = [55,66,83,99]
 df = raw_imp.copy()
 transform = True
 
-test = plot_adducts([55,66,83,99], df = raw_imp)
+test = dbdi.plot_adducts([55,66,83,99], df = raw_imp)
 test = plot_adducts(IDs, df, metadata = annotation_metadata, transform = False)
 
 plot_adducts(2,2)
@@ -97,4 +109,12 @@ test.gca().get_title()
 
 
 
-specs_aligned = specs_aligned.apply(lambda col:pd.to_numeric(col, errors='coerce'))
\ No newline at end of file
+specs_aligned = specs_aligned.apply(lambda col:pd.to_numeric(col, errors='coerce'))
+
+#%% 
+path = r'D:\Users\.....'
+path = path.replace('\\' , '/')
+
+
+
+
